# Электронная почта и почтовый сервер

## Как настроить внутреннюю почту для отправки через SMTP?

По умолчанию электронные письма, созданные Hestia (уведомления, забытый пароль, журналы обновлений и т. д.), отправляются на внутреннюю почту. Если хотите, вы можете настроить отправку почты через учетную запись SMTP.

Выполните следующий скрипт и следуйте инструкциям:

```bash
bash /usr/local/hestia/install/upgrade/manual/configure-server-smtp.sh
```

## Я не могу отправить электронную почту

Сначала проверьте, открыт ли порт 25 для исходящего трафика. Многие провайдеры блокируют порт 25 по умолчанию для борьбы со спамом.

Для этого выполните следующую команду:

```bash
telnet ASPMX.L.GOOGLE.COM 25
```

Если подключение прошло успешно, вы увидите что-то похожее на это:

```bash
Попытка 2a00:1450:400c:c00::1b...
Подключено к ASPMX.L.GOOGLE.COM.
Символ экранирования — '^]'.
220 mx.google.com ESMTP a7si1253985wrr.455 - gsmtp
```

Если нет, у вас есть 2 варианта:

1. Свяжитесь со своим провайдером и попросите его открыть порт 25 для исходящего трафика.
2. Настройте почтовый ретранслятор в настройках почтового домена или настройте его в целом для сервера в системных настройках. Для этого вам нужно использовать службу ретрансляции SMTP, например:
- [Amazon SES](https://aws.amazon.com/ses/)
- [SMTP2GO](https://www.smtp2go.com)
- [Sendinblue](https://www.sendinblue.com)

## Что такое служба ретрансляции SMTP и как ее настроить

Ретрансляция почты SMTP — это процесс передачи электронной почты с одного сервера на другой для доставки. Часто электронная почта с сервера блокируется поставщиком услуг из-за страха перед спамом. Или репутация IP настолько низкая, что вся почта сразу попадает в папку со спамом. Чтобы предотвратить такие проблемы, многие компании предлагают ретрансляцию SMTP, которая берет на себя часть доставки. Поскольку они отправляют много электронной почты через одни и те же IP-адреса, у них лучшая репутация.

Для настройки создайте учетную запись у нужного вам провайдера или используйте его и следуйте его инструкциям по обновлению DNS. После завершения вы можете ввести учетную запись пользователя SMTP, которую они предоставляют, в настройках в разделе «Глобальный SMTP» или в разделе «Изменить почтовый домен» -> «SMTP-ретранслятор»

## Я не могу получать электронную почту

Если вы не можете получать электронную почту, убедитесь, что вы правильно настроили DNS. Если вы используете Cloudflare, отключите использование прокси для `mail.domain.tld`.

После завершения вы можете проверить конфигурацию через [MXToolBox](https://mxtoolbox.com/MXLookup.aspx).

## Как установить SnappyMail?

Вы можете установить SnappyMail, выполнив следующую команду:

```bash
v-add-sys-snappymail
```

## Могу ли я войти в бэкэнд SnappyMail

В корневой папке есть файл с именем `.snappymail`, содержащий имя пользователя и пароль:

```bash
Имя пользователя: admin_f0e5a5aa
Пароль: D0ung4naLOptuaa
Секретный ключ: admin_f0e5a5aa
```

Вы можете получить доступ к администратору, перейдя по адресу `https://webmail.domain.tld/?admin_f0e5a5aa`, и войти, используя данные, которые вы нашли в файле. Когда он больше не понадобится, удалите файл из соображений безопасности.

## Могу ли я использовать прокси-сервер Cloudflare с электронной почтой

Нет, прокси-сервер Cloudflare не работает с электронной почтой. Если вы используете электронную почту, размещенную на вашем сервере, убедитесь, что прокси для записи A `mail.domain.tld` отключен. В противном случае вы не сможете получать электронные письма. Следующие записи рекомендуются, если вы хотите использовать Hestia в качестве почтового сервера:

- Запись с именем **mail**, указывающая на IP вашего сервера.
- Запись с именем **webmail**, указывающая на IP вашего сервера.
- Запись MX с именем **@**, указывающая на `mail.domain.tld`.
- Запись TXT с именем **@**, содержащая `v=spf1 a mx ip4:your ip; \~all`
- Запись TXT с именем **\_domainkey**, содержащая `t=y; o=~;`
- Запись TXT с именем **mail.\_domainkey**, содержащая `t=y; o=~DKIM key;`
- Запись TXT с именем **\_dmarc**, содержащая `v=DMARC1; p=quarantine; sp=quarantine; adkim=s; aspf=s;`

Ключ DKIM и запись SPF можно найти в списке **Mail Domains** ([documentation](../user-guide/mail-domains.md#get-dns-records)).

## При отправке писем с моего сервера они попадают в папку со спамом

Убедитесь, что вы настроили правильные записи RDNS, SPF и DKIM.

Если это не сработает, возможно, ваш IP-адрес находится в одном или нескольких черных списках. Вы можете попробовать разблокировать его самостоятельно, но часто более простой метод — использовать SMTP и SMTP Relay с Amazon SES или другим поставщиком SMTP.

## Как включить ManageSieve?

Во время установки Hestia используйте флаг `--sieve`. Если Hestia уже установлена, по следующему пути есть скрипт обновления: `/usr/local/hestia/install/upgrade/manual/install_sieve.sh`

## Могу ли я разрешить доступ к ManageSieve через внешний почтовый клиент?

Откройте порт 4190 в брандмауэре. [Прочитайте документацию брандмауэра](./firewall.md).

## Как включить ManageSieve для Snappymail?

Отредактируйте `/etc/snappymail/data/_data_/_default_/domains/default.ini` и измените следующие параметры:

```bash
sieve_use = On
sieve_allow_raw = Off
sieve_host = "localhost"
sieve_port = 4190
sieve_secure = "None"
```